@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::SecurityHeader;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub register {
     my ($self, $app, $headers) = @_;
@@ -12,6 +12,7 @@ sub register {
     my @headers_list = qw(
         Strict-Transport-Security Public-Key-Pins Referrer-Policy 
         X-Content-Type-Options X-Frame-Options X-Xss-Protection
+        Content-Security-Policy
     );
 
     my %valid_headers;
@@ -30,9 +31,10 @@ sub register {
              "strict-origin-when-cross-origin",
              "unsafe-url"
          ],
-         'X-Content-Type-Options' => ['nosniff'],
-         'X-Xss-Protection'       => \&check_xp,
-         'X-Frame-Options'        => \&check_fo,
+         'X-Content-Type-Options'  => ['nosniff'],
+         'X-Xss-Protection'        => \&check_xp,
+         'X-Frame-Options'         => \&check_fo,
+         'Content-Security-Policy' => \&check_csp,
     );
 
     my %options = (
@@ -45,6 +47,7 @@ sub register {
         'X-Content-Type-Options'    => "nosniff",
         'X-Xss-Protection'          => '1; mode=block',
         'X-Frame-Options'           => 'DENY',
+        'Content-Security-Policy'   => "default-src 'self'",
     );
 
     my %security_headers;
@@ -90,6 +93,21 @@ sub register {
     });
 }
 
+sub check_csp {
+    my ($value, $options) = @_;
+
+    my $option = '';
+
+    if ( ref $value ) {
+       for my $key ( reverse sort keys %{ $value || {} } ) {
+           my $tmp_value = $value->{$key};
+           $option .= sprintf "%s-src %s; ", $key, $tmp_value;
+       }
+    }
+
+    return $option;
+}
+
 sub check_sts {
     my ($value, $options) = @_;
 
@@ -168,7 +186,7 @@ Mojolicious::Plugin::SecurityHeader
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
